<?php
/**
* Deals with all database interactions for the system
*
* Uses the PEAR DB libraries to avoid database dependency
* @package database
* @author Stewart Smith
*/
require_once($config['basedir'].'/backend/syslog.inc');
/**
* Include the PEAR DB libraries.
* @link http://pear.php.net The PEAR site (hopefully the docs have improved)
*/
require_once("DB.php");

/**
* Database handle
*
* Database Handle. Used to keep one database connection for
* the running of the script.
* @global mixed $dbh
*/
$dbh = DB::connect($config['db'],array('autofree'=>true,'persistent'=>true));

if(DB::isError($dbh))
{
 my_syslog(LOG_ERR, "Failed to connect to database. dbh Message=".$dbh->getMessage()."    dbh Dump:".var_export($dbh));
 die ($dbh->getMessage());
}

function sql_insert($table,$values)
{
  global $dbh;

  $sql = "insert into $table (";
  $sql_values = "values (";
  $fields = array();

  foreach(array_keys($values) as $key) {
    if($values[$key])
      array_push($fields,$key);
  }
  for($i=0;$i<count($fields)-1;$i++) {
    $sql.=$fields[$i].", ";
    $sql_values.=$dbh->quote($values[$fields[$i]]).", ";
  }
  $sql.=$fields[$i];
  $sql_values.=$dbh->quote($values[$fields[$i]]).")";

  $sql.=") ".$sql_values;
  my_syslog(LOG_DEBUG,"sql_insert() SQL statement: $sql");

  $result = $dbh->query($sql);
  if (DB::isError($result)) {
    my_syslog(LOG_ERR,'sql_insert error: '.$result->getMessage());
    $e = var_export($result,TRUE);
    my_syslog(LOG_ERR,"sql_insert result: $e");
  }

  return $result;
}

function sql_update($table, $fields, $where)
{
  global $dbh;
  $sql = "update $table set ";
  $f=array();
  foreach(array_keys($fields) as $key)
    array_push($f,$key);

  for($i=0;$i<count($fields)-1;$i++)
    $sql.=$f[$i].'='.$dbh->quote($fields[$f[$i]]).", ";
  $sql.=$f[$i].'='.$dbh->quote($fields[$f[$i]]);

  $sql.=' where '.$where;

  my_syslog(LOG_DEBUG,"sql_update() SQL: $sql");

  $result = $dbh->query($sql);
  if (DB::isError($result)) {
    my_syslog(LOG_ERR,'sql_update error: '.$result->getMessage());
    my_syslog(LOG_ERR,'sql_update result: '.var_export($result));
  }

 return $result;
}

function sql_select1($table, $fields, $where)
{
 global $dbh;
 $sql = "select ".$fields." from ".
      	$table." where ".$where;
 $result = $dbh->query($sql);
 my_syslog(LOG_DEBUG,'sql_select1 query: '.$sql);
 if(!DB::isError($result))
   $row = $result->fetchrow(DB_FETCHMODE_OBJECT);
 else
   {
     $row = NULL;
     my_syslog(LOG_INFO,'sql_select1 message: '.$result->getMessage());
     my_syslog(LOG_INFO,'sql_select1 result: '.var_export($result,true));
   }

 return $row;
}

function sql_select($table, $where)
{
 global $dbh;
 $sql = "select * from ".
   $table." where ".$where;
 my_syslog(LOG_ERR,'sql_select query: '.$sql);
 $result = $dbh->query($sql);
 if(!DB::isError($result))
   $row = $result->fetchrow(DB_FETCHMODE_OBJECT);
 else
   $row = NULL;

 return $row;
}

function has_permission($member_id,$activity)
{
  global $dbh,$config;

  $sql = 'select can_do from has_permission '
    .'where member_id='.$dbh->quote($member_id).' and '
    .'org_id='.$dbh->quote($config['org_id']).' and '
    .'(activity='.$dbh->quote($activity)
    ." or activity='admin') and "
    .'can_do=true';
  my_syslog(LOG_DEBUG,'has_permission query: '.$sql);
  $result = $dbh->query($sql);
  if(!DB::isError($result))
    $row = $result->fetchrow(DB_FETCHMODE_OBJECT);
  else
    {
      my_syslog(LOG_INFO,'has_permission isError: '.$result->getMessage());
      return false;
    }

  return $row->can_do;
}

function get_member_id($email)
{
  global $dbh;

  $result = sql_select1('members', 'id', 'email='.$dbh->quote($email));
  return $result->id;
}

function get_member($id,$state="current_memberships")
{
  global $dbh,$config;

  $sql = "select * from {$state} where id=".$dbh->quote($id);
  if($state=="current_memberships")
    $sql.=" and org_id=".$config['org_id'];
  $result = $dbh->query($sql);
  my_syslog(LOG_DEBUG,'get_member query: '.$sql);
  if(!DB::isError($result))
    $row = $result->fetchrow(DB_FETCHMODE_OBJECT);
  else {
    $row = NULL;
    my_syslog(LOG_INFO,"get_member error: ".var_dump($result,true));
  }

  return $row;
}

function get_member_types() {
  global $dbh,$config;
  $list = array();

  $sql = 'SELECT * FROM member_types where org_id='.$config['org_id'].' or org_id=null';
  $result = $dbh->query($sql);
  while($row = $result->fetchrow(DB_FETCHMODE_OBJECT))
    $list[] = $row;
  return $list;
}

function get_member_type($id) {
  global $dbh,$config;
  $list = array();

  $sql = 'SELECT * FROM member_types where (org_id='.$config['org_id'].' or org_id=null) and id='.$dbh->quote($id);
  my_syslog(LOG_DEBUG,'get_member_type query: '.$sql);
  $result = $dbh->query($sql);
  $row = $result->fetchrow(DB_FETCHMODE_OBJECT);

  return $row;
}

function add_qualification($name,$department,$institution)
{
 sql_insert('qualifications',
            array('name'        => $name,
                  'department'  => $department,
                  'institution' => $institution));
}

function add_org($name,$founded,$closed,$website,$contact)
{
 sql_insert('orgs', array('name'    => $name,
                          'founded' => $founded,
                          'closed'  => $closed,
                          'website' => $website,
                          'contact' => $contact));
}

function add_org_relation_type($org_id,$type,$description)
{
 sql_insert('org_relation_types', array('org_id'      => $org_id,
                                        'type'        => $type,
                                        'description' => $description));
}

function add_org_relation($org_id, $related_to_org_id, $org_relation_type_id)
{
 sql_insert('org_relations', array('org_id'               => $org_id,
                                   'related_to_org_id'    => $related_to_org_id,
                                   'org_relation_type_id' => $org_relation_type_id));
}

?>
